@@ -28,6 +28,14 @@ sub _load_class {
   $class;
 }
 
+# /foo/1/bar => foo_1_bar
+sub _sub_name {
+  local $_ = $_[1];
+  s!/!_!g;
+  s!^_+!!;
+  $_;
+}
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mango>, L<Mandel>
@@ -38,4 +46,4 @@ Jan Henning Thorsen - C<jhthorsen@cpan.org>
 
 =cut
 
-1;
\ No newline at end of file
+1;
